/* MoreBalance - load balancer and networking tool
 * Copyright (C) 2002 - 2006 Josef Spillner <josef@coolprojects.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef CONF_H
#define CONF_H

/* Forwarding to the given hosts for the given port numbers */
struct cluster_t
{
	int *ports;
	char **nodes;
	char **sockets;
	int *portopts;
	int portsnum;
	int nodesnum;
	int destport;
	int destportopts;
	char *destsocket;
	char *pattern;
	char *prelaunch;
};

/* Quality of Service */
struct qos_t
{
	int port1;
	int port2;
	long timeout;
};

/* A complete MoreBalance configuration */
struct conf_t
{
	char valid;
	struct cluster_t **cluster;
	struct qos_t **qos;
	int qosnum;
	int clusternum;
	int verbose;
};

/* Type definitions */
typedef struct conf_t conf;
typedef struct cluster_t cluster;
typedef struct qos_t qos;

/* Read in a configuration */
conf conf_read(const char *filename);

/* Read a single string */
conf conf_readstring(const char *string);

/* Optimize a configuration */
void conf_optimize(conf *c);

/* Dump a configuration to stdout */
void conf_dump(conf c);

/* Check for validity of configuration */
void conf_check(conf c);

#endif

